@@ -13,12 +13,12 @@ from .preprocess import (
     BlurInMask, BlurToFWHM, ClipLevel, DegreeCentrality, Despike, Detrend, ECM,
     Fim, Fourier, Hist, LFCD, Maskave, Means, OutlierCount, QualityIndex,
     ROIStats, Retroicor, Seg, SkullStrip, TCorr1D, TCorrMap, TCorrelate, TNorm,
-    TProject, TShift, Volreg, Warp, QwarpPlusMinus, Qwarp)
+    TProject, TShift, TSmooth, Volreg, Warp, QwarpPlusMinus, Qwarp)
 from .svm import (SVMTest, SVMTrain)
 from .utils import (
     ABoverlap, AFNItoNIFTI, Autobox, Axialize, BrickStat, Bucket, Calc, Cat,
     CatMatvec, CenterMass, ConvertDset, Copy, Dot, Edge3, Eval, FWHMx,
-    MaskTool, Merge, Notes, NwarpApply, NwarpCat, OneDToolPy, Refit, Resample,
-    TCat, TCatSubBrick, TStat, To3D, Unifize, Undump, ZCutUp, GCOR, Zcat,
-    Zeropad)
+    LocalBistat, Localstat, MaskTool, Merge, Notes, NwarpApply, NwarpAdjust,
+    NwarpCat, OneDToolPy, Refit, ReHo, Resample, TCat, TCatSubBrick, TStat,
+    To3D, Unifize, Undump, ZCutUp, GCOR, Zcat, Zeropad)
 from .model import (Deconvolve, Remlfit, Synthesize)
