@@ -4,7 +4,8 @@ from __future__ import absolute_import
 # -*- coding: utf-8 -*-
 
 from .utils import (Mesh2PVE, Generate5tt, BrainMask, TensorMetrics,
-                    ComputeTDI, TCK2VTK, MRMath, MRConvert, DWIExtract)
+                    ComputeTDI, TCK2VTK, MRMath, MRConvert, MRResize,
+                    DWIExtract)
 from .preprocess import (ResponseSD, ACTPrepareFSL, ReplaceFSwithFIRST,
                          DWIDenoise, MRDeGibbs, DWIBiasCorrect)
 from .tracking import Tractography
