@@ -16,7 +16,6 @@ standard_library.install_aliases()
 import os
 import re
 import numpy as np
-import nibabel as nb
 
 from ..base import (traits, TraitedSpec, DynamicTraitedSpec, File, Undefined,
                     isdefined, OutputMultiPath, InputMultiPath, BaseInterface,
@@ -217,7 +216,7 @@ class RenameInputSpec(DynamicTraitedSpec):
 
 
 class RenameOutputSpec(TraitedSpec):
-    out_file = traits.File(
+    out_file = File(
         exists=True, desc="softlink to original file with new name")
 
 
@@ -255,7 +254,7 @@ class Rename(SimpleInterface, IOBase):
 
     >>> rename3 = Rename(format_string="%(subject_id)s_%(seq)s_run%(run)02d.nii")
     >>> rename3.inputs.in_file = os.path.join(datadir, "func_epi_1_1.nii")
-    >>> rename3.inputs.parse_string = "func_(?P<seq>\w*)_.*"
+    >>> rename3.inputs.parse_string = r"func_(?P<seq>\w*)_.*"
     >>> rename3.inputs.subject_id = "subj_201"
     >>> rename3.inputs.run = 2
     >>> res = rename3.run()          # doctest: +SKIP
@@ -416,7 +415,7 @@ class AssertEqual(BaseInterface):
     input_spec = AssertEqualInputSpec
 
     def _run_interface(self, runtime):
-
+        import nibabel as nb
         data1 = nb.load(self.inputs.volume1).get_data()
         data2 = nb.load(self.inputs.volume2).get_data()
 
