@@ -6,17 +6,20 @@ from io import open
 import click
 
 from .instance import list_interfaces
-from .utils import (CONTEXT_SETTINGS,
-                    UNKNOWN_OPTIONS,
-                    ExistingDirPath,
-                    ExistingFilePath,
-                    UnexistingFilePath,
-                    RegularExpression,
-                    PythonModule,
-                    check_not_none,)
+from .utils import (
+    CONTEXT_SETTINGS,
+    UNKNOWN_OPTIONS,
+    ExistingDirPath,
+    ExistingFilePath,
+    UnexistingFilePath,
+    RegularExpression,
+    PythonModule,
+    check_not_none,
+)
 
 from .. import __version__
 
+
 # declare the CLI group
 @click.group(context_settings=CONTEXT_SETTINGS)
 def cli():
@@ -25,8 +28,12 @@ def cli():
 
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument('logdir', type=ExistingDirPath, callback=check_not_none)
-@click.option('-r', '--regex', type=RegularExpression(), callback=check_not_none,
-              help='Regular expression to be searched in each traceback.')
+@click.option(
+    '-r',
+    '--regex',
+    type=RegularExpression(),
+    callback=check_not_none,
+    help='Regular expression to be searched in each traceback.')
 def search(logdir, regex):
     """Search for tracebacks content.
 
@@ -48,14 +55,25 @@ def search(logdir, regex):
 
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument('crashfile', type=ExistingFilePath, callback=check_not_none)
-@click.option('-r', '--rerun', is_flag=True, flag_value=True,
-              help='Rerun crashed node.')
-@click.option('-d', '--debug', is_flag=True, flag_value=True,
-              help='Enable Python debugger when re-executing.')
-@click.option('-i', '--ipydebug', is_flag=True, flag_value=True,
-              help='Enable IPython debugger when re-executing.')
-@click.option('-w', '--dir', type=ExistingDirPath,
-              help='Directory where to run the node in.')
+@click.option(
+    '-r', '--rerun', is_flag=True, flag_value=True, help='Rerun crashed node.')
+@click.option(
+    '-d',
+    '--debug',
+    is_flag=True,
+    flag_value=True,
+    help='Enable Python debugger when re-executing.')
+@click.option(
+    '-i',
+    '--ipydebug',
+    is_flag=True,
+    flag_value=True,
+    help='Enable IPython debugger when re-executing.')
+@click.option(
+    '-w',
+    '--dir',
+    type=ExistingDirPath,
+    help='Directory where to run the node in.')
 def crash(crashfile, rerun, debug, ipydebug, dir):
     """Display Nipype crash files.
 
@@ -71,9 +89,8 @@ def crash(crashfile, rerun, debug, ipydebug, dir):
     if debug == 'ipython':
         import sys
         from IPython.core import ultratb
-        sys.excepthook = ultratb.FormattedTB(mode='Verbose',
-                                             color_scheme='Linux',
-                                             call_pdb=1)
+        sys.excepthook = ultratb.FormattedTB(
+            mode='Verbose', color_scheme='Linux', call_pdb=1)
     display_crash_file(crashfile, rerun, debug, dir)
 
 
@@ -93,13 +110,20 @@ def show(pklz_file):
 
 
 @cli.command(context_settings=UNKNOWN_OPTIONS)
-@click.argument('module', type=PythonModule(), required=False,
-                callback=check_not_none)
+@click.argument(
+    'module', type=PythonModule(), required=False, callback=check_not_none)
 @click.argument('interface', type=str, required=False)
-@click.option('--list', is_flag=True, flag_value=True,
-              help='List the available Interfaces inside the given module.')
-@click.option('-h', '--help', is_flag=True, flag_value=True,
-              help='Show help message and exit.')
+@click.option(
+    '--list',
+    is_flag=True,
+    flag_value=True,
+    help='List the available Interfaces inside the given module.')
+@click.option(
+    '-h',
+    '--help',
+    is_flag=True,
+    flag_value=True,
+    help='Show help message and exit.')
 @click.pass_context
 def run(ctx, module, interface, list, help):
     """Run a Nipype Interface.
@@ -128,11 +152,10 @@ def run(ctx, module, interface, list, help):
     elif (module_given and interface):
         # create the argument parser
         description = "Run {}".format(interface)
-        prog = " ".join([ctx.command_path,
-                         module.__name__,
-                         interface] + ctx.args)
-        iface_parser = argparse.ArgumentParser(description=description,
-                                               prog=prog)
+        prog = " ".join(
+            [ctx.command_path, module.__name__, interface] + ctx.args)
+        iface_parser = argparse.ArgumentParser(
+            description=description, prog=prog)
 
         # instantiate the interface
         node = getattr(module, interface)()
@@ -152,11 +175,13 @@ def run(ctx, module, interface, list, help):
             args = iface_parser.parse_args(args=ctx.args)
             run_instance(node, args)
 
+
 @cli.command(context_settings=CONTEXT_SETTINGS)
 def version():
     """Print current version of Nipype."""
     click.echo(__version__)
 
+
 @cli.group()
 def convert():
     """Export nipype interfaces to other formats."""
@@ -164,42 +189,77 @@ def convert():
 
 
 @convert.command(context_settings=CONTEXT_SETTINGS)
-@click.option("-i", "--interface", type=str, required=True,
-              help="Name of the Nipype interface to export.")
-@click.option("-m", "--module", type=PythonModule(), required=True,
-              callback=check_not_none,
-              help="Module where the interface is defined.")
-@click.option("-o", "--output", type=UnexistingFilePath, required=True,
-              callback=check_not_none,
-              help="JSON file name where the Boutiques descriptor will be written.")
-@click.option("-t", "--ignored-template-inputs", type=str, multiple=True,
-              help="Interface inputs ignored in path template creations.")
-@click.option("-d", "--docker-image", type=str,
-              help="Name of the Docker image where the Nipype interface is available.")
-@click.option("-r", "--docker-index", type=str,
-              help="Docker index where the Docker image is stored (e.g. http://index.docker.io).")
-@click.option("-n", "--ignore-template-numbers", is_flag=True, flag_value=True,
-              help="Ignore all numbers in path template creations.")
-@click.option("-v", "--verbose", is_flag=True, flag_value=True,
-              help="Enable verbose output.")
-def boutiques(interface, module, output, ignored_template_inputs,
-              docker_image, docker_index, ignore_template_numbers,
-              verbose):
+@click.option(
+    "-i",
+    "--interface",
+    type=str,
+    required=True,
+    help="Name of the Nipype interface to export.")
+@click.option(
+    "-m",
+    "--module",
+    type=PythonModule(),
+    required=True,
+    callback=check_not_none,
+    help="Module where the interface is defined.")
+@click.option(
+    "-o",
+    "--output",
+    type=UnexistingFilePath,
+    required=True,
+    callback=check_not_none,
+    help="JSON file name where the Boutiques descriptor will be "
+    "written.")
+@click.option(
+    "-c",
+    "--container-image",
+    required=True,
+    type=str,
+    help="Name of the container image where the tool is installed.")
+@click.option(
+    "-p",
+    "--container-type",
+    required=True,
+    type=str,
+    help="Type of container image (Docker or Singularity).")
+@click.option(
+    "-x",
+    "--container-index",
+    type=str,
+    help="Optional index where the image is available (e.g. "
+    "http://index.docker.io).")
+@click.option(
+    "-g",
+    "--ignore-inputs",
+    type=str,
+    multiple=True,
+    help="List of interface inputs to not include in the descriptor.")
+@click.option(
+    "-v",
+    "--verbose",
+    is_flag=True,
+    flag_value=True,
+    help="Print information messages.")
+@click.option(
+    "-a",
+    "--author",
+    type=str,
+    help="Author of the tool (required for publishing).")
+@click.option(
+    "-t",
+    "--tags",
+    type=str,
+    help="JSON string containing tags to include in the descriptor,"
+         "e.g. \"{\"key1\": \"value1\"}\"")
+def boutiques(module, interface, container_image, container_type, output,
+              container_index, verbose, author, ignore_inputs, tags):
     """Nipype to Boutiques exporter.
 
     See Boutiques specification at https://github.com/boutiques/schema.
     """
     from nipype.utils.nipype2boutiques import generate_boutiques_descriptor
 
-    # Generates JSON string
-    json_string = generate_boutiques_descriptor(module,
-                                                interface,
-                                                ignored_template_inputs,
-                                                docker_image,
-                                                docker_index,
-                                                verbose,
-                                                ignore_template_numbers)
-
-    # Writes JSON string to file
-    with open(output, 'w') as f:
-        f.write(json_string)
+    # Generates JSON string and saves it to file
+    generate_boutiques_descriptor(
+        module, interface, container_image, container_type, container_index,
+        verbose, True, output, author, ignore_inputs, tags)
